@@ -75,7 +75,12 @@ pub struct Worker {
 }
 
 pub fn new_worker() -> Worker {
-  Worker { node: vec![0; 6 * 0x8000000], size: 0, free: vec![vec![]; 16], cost: 0 }
+  Worker {
+    node: vec![0; 6 * 0x8000000],
+    size: 0,
+    free: vec![vec![]; 16],
+    cost: 0
+  }
 }
 
 // Globals
@@ -208,7 +213,7 @@ pub fn clear(mem: &mut Worker, loc: u64, size: u64) {
 }
 
 pub fn collect(mem: &mut Worker, term: Lnk) {
-  let mut stack: Vec<Lnk> = Vec::new();
+  let mut stack : Vec<Lnk> = Vec::new();
   let mut next = term;
   loop {
     let term = next;
@@ -276,50 +281,50 @@ pub fn collect(mem: &mut Worker, term: Lnk) {
 }
 
 //pub fn collect(mem: &mut Worker, term: Lnk) {
-//match get_tag(term) {
-//DP0 => {
-//link(mem, get_loc(term, 0), Era());
-////r_educe(mem, get_loc(ask_arg(mem,term,1),0));
-//}
-//DP1 => {
-//link(mem, get_loc(term, 1), Era());
-////r_educe(mem, get_loc(ask_arg(mem,term,0),0));
-//}
-//VAR => {
-//link(mem, get_loc(term, 0), Era());
-//}
-//LAM => {
-//if get_tag(ask_arg(mem, term, 0)) != ERA {
-//link(mem, get_loc(ask_arg(mem, term, 0), 0), Era());
-//}
-//collect(mem, ask_arg(mem, term, 1));
-//clear(mem, get_loc(term, 0), 2);
-//}
-//APP => {
-//collect(mem, ask_arg(mem, term, 0));
-//collect(mem, ask_arg(mem, term, 1));
-//clear(mem, get_loc(term, 0), 2);
-//}
-//PAR => {
-//collect(mem, ask_arg(mem, term, 0));
-//collect(mem, ask_arg(mem, term, 1));
-//clear(mem, get_loc(term, 0), 2);
-//}
-//OP2 => {
-//collect(mem, ask_arg(mem, term, 0));
-//collect(mem, ask_arg(mem, term, 1));
-//clear(mem, get_loc(term, 0), 2);
-//}
-//U32 => {}
-//CTR | CAL => {
-//let arity = get_ari(term);
-//for i in 0..arity {
-//collect(mem, ask_arg(mem, term, i));
-//}
-//clear(mem, get_loc(term, 0), arity);
-//}
-//_ => {}
-//}
+  //match get_tag(term) {
+    //DP0 => {
+      //link(mem, get_loc(term, 0), Era());
+      ////r_educe(mem, get_loc(ask_arg(mem,term,1),0));
+    //}
+    //DP1 => {
+      //link(mem, get_loc(term, 1), Era());
+      ////r_educe(mem, get_loc(ask_arg(mem,term,0),0));
+    //}
+    //VAR => {
+      //link(mem, get_loc(term, 0), Era());
+    //}
+    //LAM => {
+      //if get_tag(ask_arg(mem, term, 0)) != ERA {
+        //link(mem, get_loc(ask_arg(mem, term, 0), 0), Era());
+      //}
+      //collect(mem, ask_arg(mem, term, 1));
+      //clear(mem, get_loc(term, 0), 2);
+    //}
+    //APP => {
+      //collect(mem, ask_arg(mem, term, 0));
+      //collect(mem, ask_arg(mem, term, 1));
+      //clear(mem, get_loc(term, 0), 2);
+    //}
+    //PAR => {
+      //collect(mem, ask_arg(mem, term, 0));
+      //collect(mem, ask_arg(mem, term, 1));
+      //clear(mem, get_loc(term, 0), 2);
+    //}
+    //OP2 => {
+      //collect(mem, ask_arg(mem, term, 0));
+      //collect(mem, ask_arg(mem, term, 1));
+      //clear(mem, get_loc(term, 0), 2);
+    //}
+    //U32 => {}
+    //CTR | CAL => {
+      //let arity = get_ari(term);
+      //for i in 0..arity {
+        //collect(mem, ask_arg(mem, term, i));
+      //}
+      //clear(mem, get_loc(term, 0), arity);
+    //}
+    //_ => {}
+  //}
 //}
 
 pub fn inc_cost(mem: &mut Worker) {
@@ -496,8 +501,7 @@ pub fn reduce(
               inc_cost(mem);
               subst(mem, ask_arg(mem, term, 0), ask_arg(mem, arg0, 0));
               subst(mem, ask_arg(mem, term, 1), ask_arg(mem, arg0, 1));
-              let _done =
-                link(mem, host, ask_arg(mem, arg0, if get_tag(term) == DP0 { 0 } else { 1 }));
+              let _done = link(mem, host, ask_arg(mem, arg0, if get_tag(term) == DP0 { 0 } else { 1 }));
               clear(mem, get_loc(term, 0), 3);
               clear(mem, get_loc(arg0, 0), 2);
               init = 1;
@@ -770,7 +774,7 @@ pub fn show_lnk(x: Lnk) -> String {
       F32 => "F32",
       OUT => "OUT",
       NIL => "NIL",
-      _ => "?",
+      _   => "?",
     };
     format!("{}{}:{:x}:{:x}", tgs, ari, ext, val)
   }
@@ -903,7 +907,7 @@ pub fn show_term(
           0xD => ">=",
           0xE => ">",
           0xF => "!=",
-          _ => "?e",
+          _   => "?e",
         };
         format!("({} {} {})", symb, val0, val1)
       }
@@ -944,10 +948,8 @@ pub fn show_term(
     let what = String::from("?h");
     //let kind = kinds.get(&key).unwrap_or(&0);
     let name = names.get(&pos).unwrap_or(&what);
-    let nam0 =
-      if ask_lnk(mem, pos + 0) == Era() { String::from("*") } else { format!("a{}", name) };
-    let nam1 =
-      if ask_lnk(mem, pos + 1) == Era() { String::from("*") } else { format!("b{}", name) };
+    let nam0 = if ask_lnk(mem, pos + 0) == Era() { String::from("*") } else { format!("a{}", name) };
+    let nam1 = if ask_lnk(mem, pos + 1) == Era() { String::from("*") } else { format!("b{}", name) };
     text.push_str(&format!(
       "\ndup {} {} = {};",
       //kind,
